#
# spec file for package python-gi-docgen
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           python-gi-docgen
Version:        2024.1
Release:        1.2
Summary:        A documentation generator for GObject-based libraries
# For reference, as some scripts are known to reorder things:
#               (Apache-2.0 OR GPL-3.0-or-later) AND CC0-1.0 AND MIT AND OFL-1.1
License:        (Apache-2.0 OR GPL-3.0-or-later) AND CC0-1.0 AND MIT AND OFL-1.1
URL:            https://gitlab.gnome.org/GNOME/gi-docgen
Source:         https://files.pythonhosted.org/packages/source/g/gi-docgen/gi_docgen-%{version}.tar.gz
Source98:       README.license
Source99:       %{name}-rpmlintrc

BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
## Build system dependencies
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
##
BuildRequires:  python3-Jinja2
BuildRequires:  python3-Markdown
BuildRequires:  python3-MarkupSafe
BuildRequires:  python3-Pygments
BuildRequires:  python3-packaging
BuildRequires:  python3-typogrify

Requires:       python3-Jinja2
Requires:       python3-Markdown > 3.2.0
Requires:       python3-MarkupSafe
Requires:       python3-Pygments
Requires:       python3-packaging
Requires:       python3-typogrify
Requires:       (python3-tomli if ((python310-base with python3-base) or (python39-base with python3-base)))
Requires:       (python3-tomli if python3-base < 3.7)

Obsoletes:      python38-gi-docgen < %{version}
BuildArch:      noarch
%python_subpackages

%description
GI-DocGen is a document generator for GObject-based libraries.
GObject is the base type system of the GNOME project. GI-Docgen
reuses the introspection data generated by GObject-based libraries
to generate the API reference of these libraries, as well as other
ancillary documentation.

%prep
%autosetup -n gi_docgen-%{version} -p1
# Copy README.license to the source tree, so we can use the %%doc macro on it.
cp %{SOURCE98} .

%build
%python3_build

%install
%python3_install
%fdupes %{buildroot}%{python3_sitelib}

%files %{python_files}
%doc README.md README.license
%license LICENSES/Apache-2.0.txt
%license LICENSES/GPL-3.0-or-later.txt
%license LICENSES/MIT.txt
%license LICENSES/OFL-1.1.txt
%license LICENSES/CC0-1.0.txt
%{_bindir}/gi-docgen
%{python3_sitelib}/gidocgen/
%{python3_sitelib}/gi_docgen-%{version}-py%{python3_version}.egg-info/
%{_mandir}/man1/gi-docgen.1%{?ext_man}
%{_datadir}/pkgconfig/gi-docgen.pc

%changelog
* Tue May 21 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2024.1:
  + Added
  - Add unit testing for link syntax
  - Support link to enumeration members
  - Add favicon support
  - Add proper anchor for enum members
  - Parse optional anchors in links
  - Generate a link to finish functions
  - Add 'inline' to C declarations for inline callables
  - Make the logo a link to the index
  - Clear search when pressing Escape
  + Changed
  - Update the wording for transfer modes
  - Turn deprecation notices into admonitions
  - Improve filesystem string type docs
  + Fixed
  - Fix doubled paragraph tags around descriptions
  - Append period after last line in more cases
  - Documentation fixes
  - Use the basename of the urlmap file
  + Removed
  - Revert "generate: Add fallback for missing "since""
* Tue Feb 20 2024 Michael Gorse <mgorse@suse.com>
- Require python3-tomli if python3-base is on v3.6 (ie, SLE 15).
* Sat Nov 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2023.3:
  + Fixed:
  - Add missing dependency
  - Add missing test data to the source archive
- Changes from version 2023.2:
  + Added:
  - Use packaging module to properly compare versions
  - Add "implements" in class definition pseudocode
  - Ignore the first class instance struct field
  - Parse default-value attribute
  - Test the gtk-doc sigil parsing
  - Support admonitions in docblocks
  - Add link to the extra content files location in the source
    repository
  - Search for GIR XML in $GI_GIR_PATH and /usr/share/gir-1.0
  - Add fallback for missing "since"
  + Changed:
  - Redesign the search results
  - Redesign the index for enumeration types
  + Fixed:
  - Match dependencies list in the index and sidebar
  - Use KeyboardEvent.key to focus search input
  - Build fixes for subproject use
  - Remove display:flex from headings
  - Split transfer notes based on direction
  - Clarify signal flags
  - Hide build section if empty
  - Always explicitely use utf-8 when reading/writing files
  - Use color-scheme: dark when in dark mode
- Drop python3-tomli BuildRequires: No longer needed.
- Add python3-packaging BuildRequires/Requires: New dependency.
* Tue Jan 10 2023 Luciano Santos <luc14n0@opensuse.org>
- Drop python3-coverage and python3-green package sugestion as they
  are really meant for development, not for packaging purposes.
- Drop update-alternatives facility. GI-DocGen turned out to be a
  non-user-facing software, so there's no need to have alternatives
  for it and we're already producing only the main Python 3 flavor
  anyway.
- Change URL tag from gitlab.gnome.org/ebassi/gi-docgen to
  gitlab.gnome.org/GNOME/gi-docgen. GI-DocGen is an official
  project under the GNOME umbrella now.
- Update "Apache-2.0 AND GPL-3.0-or-later AND CC0-1.0" License tag
  to "(Apache-2.0 OR GPL-3.0-or-later) AND CC0-1.0 AND MIT AND
  OFL-1.1", to account for a couple of missed licenses, and a
  choice between Apache and GPL licenses.
- Following the changes from version 2023.1, use tomli Python
  module as build and runtime requirement for Python older than
  3.11. Otherwise, the tomllib Python module, provided by the
  standard library, is going to be used instead.
* Fri Jan  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2023.1:
  + Added: Use tomlib for Python >= 3.11 and tomli/toml for Python
    < 3.11
  + Fixed: Use the proper link fragment for interface prerequisite
* Mon Nov 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2022.2:
  + Use const.*.html instead of constant.*.html for search index
    links
  + Remove "terms" from index.json, rewrite commandline search to
    work without it
  + Add interface type description
  + Fix failure to generate link to error domain
  + Make log.log() thread safe
  + Quote string constant values
  + Set the license of the generated documentation
  + Support (scope forever)
  + Add a way to frame images
  + Use the appropriate namespace for indices
  + Fix type annotations for Repository packages and c_includes
  + Add py.typed to comply with PEP561
  + Add links to external classes in the hierarchy
  + Use definition lists for callable arguments
  + Improve styles
  + Use definition lists for callable arguments
  + Clarify generated description for GError arguments
  + Clarify generated description for nullable in/out arguments
  + Add emblems for versions and stability
  + Require a sufficient minimum dependency of markdown
  + Add a "serve" command
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2022.1:
  + Do not qualify type names that are already qualified
  + Handle implied zero-terminated=1 attribute
  + Display type note for strings inside arrays
  + Use C types for string and property types
  + Add support for OpenSearch
  + Fix links to callback types
  + Validate the "type" link fragment
  + Split type and array parsing
  + Add exception mode to the GIR parser
  + Handle missing type information in arguments
  + Add more contrast to the dimmed text class
  + Improve classification of pointer arguments
  + Add blurb when eliding inherited methods
  + Include bits in structure fields
  + Add a test suite for the gi-docgen link generator
  + Style keyboard shortcuts like libadwaita
  + Do not require a message for deprecations
  + Add anchors for enumeration values
  + Add a ToC for the page navigation side bar
  + Fix pointer type detection
  + Note functions that are not introspectable or that have been
    shadowed
  + Split "related" libraries from "dependencies"
- Drop 114.patch: Fixed upstream.
* Fri Oct 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add 114.patch: gir: Do not qualify type names that are already
  qualified.
* Tue Oct 26 2021 Yifan Jiang <yfjiang@suse.com>
- Specify python-Markdown version to at least 3.2.0, because
  permalink_class options in TOC used by gi-docgen was introduced
  on 3.2.0:
  https://github.com/Python-Markdown/markdown/commit/1f3ec538a2acf25607253fc7c7a992950463931d
* Fri Oct 22 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2021.8:
  + Allow `id` fragments to link across namespace boundaries
  + Support links to have custom text
  + Decrease the max font size
  + Improve output for properties and signals
  + Save last search in the history
  + Don't crash on unlabelled array elements
  + Move type functions near constructors
  + Switch to Solarized for syntax highlighting
  + Use the C type for callback types in search results
  + Generate proper cross-reference links
  + Parse and use new gobject-introspection property attributes
  + Properly identify (type, gpointer) types
  + List the interface implementations in a namespace
  + List the class descendants in a namespace
* Tue Aug 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2021.7:
  + Add a "check" sub-command
  + Allow defining multiple content directories
  + Detect gtk-doc code blocks for JavaScript
  + Multiple changes to the basic template
  + Add in-page content navigation
  + Filter hidden data from indices
  + Allow defining hidden symbols matching a regular expression
  + Handle (attribute element-type) annotation for GListModel
  + Fix class method linking
  + Fix links to callback type arguments
  + Fix argument listing in class methods
  + Don't grab the 's' key when the sidebar is hidden
  + Index the extra content files for search
  + Fix gtk-doc sigil handling in code blocks
  + Re-instate gtk-doc `()` function detection
- Switch to building only default flavour of python3.
* Fri Mar 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Initial package, version 2021.2
